# MakePdfEasily


### Choose a language
[Arabic - العربية](https://github.com/AliAdnanc7/MakePdfEasily/blob/main/languages/Arabic.md)


### to install:
```bash
pip3 install MakePdfEasily
or 
pip install MakePdfEasily
```
### Examples

```bash
import MakePdfEasily 

from  MakePdfEasily import *
#Create a folder first and put all the pictures in it
print(MakePdf("folder","hi.pdf"))

#Merge pdf files

print(mergerPDf("folder","hi.pdf"))
```

### Bot Telegram with MakePdfEasily

[pytelegrambotapi](https://github.com/Ali-Adnan219/MakePdfEasily/blob/main/Examples/Telegram%20bot/pytelegrambotapi%20with%20MakePdfEasily/main.py)